IntoSerdeProblem

Trait IntoSerdeProblem 

pub trait IntoSerdeProblem {
    // Required methods
    fn into_serde_serialize_problem(self) -> SerdeProblem;
    fn into_serde_deserialize_problem(self) -> SerdeProblem;
}
Available on crate feature serde only.
Convert into a SerdeProblem.

Required Methods

fn into_serde_serialize_problem(self) -> SerdeProblem

Convert into a SerdeProblem via SerializationError.

You probably want to call from_serde_problem to eventually map it back and avoid re-wrapping it and thus losing the causation chain.

fn into_serde_deserialize_problem(self) -> SerdeProblem

Convert into a SerdeProblem via DeserializationError.

You probably want to call from_serde_problem to eventually map it back and avoid re-wrapping it and thus losing the causation chain.

Implementors

Source

impl<ErrorT> IntoSerdeProblem for ErrorT
where ErrorT: 'static + Error + Send + Sync,