pub trait IntoSerdeProblem {
// Required methods
fn into_serde_serialize_problem(self) -> SerdeProblem;
fn into_serde_deserialize_problem(self) -> SerdeProblem;
}Available on crate feature
serde only.Expand description
Convert into a SerdeProblem.
Required Methods
Sourcefn into_serde_serialize_problem(self) -> SerdeProblem
fn into_serde_serialize_problem(self) -> SerdeProblem
Convert into a SerdeProblem via SerializationError.
You probably want to call from_serde_problem to eventually map it back and avoid re-wrapping it and thus losing the causation chain.
Sourcefn into_serde_deserialize_problem(self) -> SerdeProblem
fn into_serde_deserialize_problem(self) -> SerdeProblem
Convert into a SerdeProblem via DeserializationError.
You probably want to call from_serde_problem to eventually map it back and avoid re-wrapping it and thus losing the causation chain.